from random import choice
try:
    from AffirmationText import affirmations as affirmations
except:
    from Affirmations.AffirmationText import affirmations as affirmations


def affirm(function):
    def wrapper(*args):
        func = function(*args)
        print(choice(affirmations))
        return func
    return wrapper

if __name__ == "__main__":
    pass



affirmations = [
    "You're Great!",
    "Way to Go!",
    "Woo hoo!",
    "You got out of bed this morning!",
    "Keep going!",
    "What nimble fingers you have!",
    "Awesome!",
    "Did you ever know that you're my hero?",
    "Lookin' good.",
    "You're on your way to glory",
    "You can do it!",
    "Coding is hard! And you did great!",
    "''You miss 100\% of the shots you don't take' - Wayne Gretzky' - Michael Scott (And you took your shot! Way to go!)",
    "You rock my socks off",
    "You're too cool for school!",
    "Daaammmmnnnn, that's some sweet code",
    "Five! Six! Seven! Eight! What coder does this code appreciate!? You! You! Gooooo you!",
    "I think you're neat!",
    "High five!!!",
    "If you were an American president, you'd be Code-braham Lincoln",
    "Great job! Go get a coffee",
    "\U0001F44D\U0001F44D\U0001F44D\U0001F44D\U0001F44D\U0001F44D",
    "If I had hands, you'd be getting a high five",
    "If I could rearrange the alphabet I would put 'U' 'R' 'GR8' together. Then I would learn what an alphabet is.",
    "\U0001F525\U0001F525\U0001F525 Your Code \U0001F525\U0001F525\U0001F525",
    "Woo hoo! Time to celebrate!",
    "Live, Laugh, Love, Code.",
    "You're the bee's knees",
    "Boom! Awesome code!",
    "You deserve a ninja turtle named after you",
    "10 out of 10 dentists would recommend you",
    "\U0001F60E",
    "\U0001FAF5\U0001F4BB\U0001F4C8\U0001F600\U0001F30E",
    "It ran! Time to celebrate \U0001F942",
    "Your code ran! Weeeee!",
    "If this were the bachelor(ette) your code would get a rose",
    "What's it like to be so amazing?",
    "Hey! Call up that friend you've been meaning to hang out with.",
    "Don't stop believing in yourself!",
    "Don't stop ever not stopping to never stop being awesome",
    "You did so great, you should look up pictures of puppies",
    "This is better than opening a Nintendo 64 on Christmas morning 1996",
    "**celebratory karate moves**",
    "You're making the world a better place!",
    "You should twitch stream yourself coding",
    "You got this! :)",
    "Crushin' it!",
    "Amazing!",
    "Ayyyyyyy! Well done!",
    "Awwwwwwwwwyeah!",
    "Don't stop believing, and hold onto that feeling!",
    "You're definitely making your way downtown!",
    "I'd walk a thousand miles just to see your code!",
    "Sick moves, fam!",
    "You da GOAT!",
    "This code is FIYAH, and so are you!"
]



from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

long_description = (here / 'README.md').read_text(encoding='utf-8')

setup(
    name='Affirmations', 
    version='0.0.9',
    description='Randomly adds affirming print statements to functions.',
    long_description=long_description,
    long_description_content_type='text/markdown', 
    url='https://github.com/TimNicholsonShaw/affirmation',  
    author='Tim Nicholson-Shaw',
    author_email='timnicholsonshaw@gmail.com',
    classifiers=[ 
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3 :: Only',
    ],
    keywords='Self-care, Self-compassion',
    package_dir={'': 'src'},
    packages=find_packages(where='src'),
    python_requires='>=3.6',
    install_requires=[],

    project_urls={ 
        'GitHub': 'https://github.com/TimNicholsonShaw/affirmation',

    },
)